#!/usr/bin/env node
"use strict";
const index_1 = require("../src/index");
const nodevolution_framework_1 = require("nodevolution-framework");
let cliArguments = process.argv.slice(2);
let commandArguments = new index_1.CommandArguments(cliArguments);
let logLevel = commandArguments.hasOption("debug") ? nodevolution_framework_1.LogLevel.Debug : nodevolution_framework_1.LogLevel.Info;
let cli = new index_1.CLI();
cli.initialize(logLevel)
    .then(() => {
    let version = require("../package.json").version;
    if (commandArguments.hasOption("version") || commandArguments.hasOption("v")) {
        console.log(version);
        return process.exit(0);
    }
    if (commandArguments.hasOption("help") || commandArguments.hasOption("h")) {
        console.log(`Welcome to nodEvolution ${version}`);
        console.log(`Usage:`);
        console.log(`nx [command] [arguments...] [--options...]`);
        console.log(``);
        console.log(`# nx           -- initializes a new configuration in the current working directory`);
        return process.exit(0);
    }
    let commandName = commandArguments.hasArguments === false ? "config" : cliArguments[0].toLowerCase();
    let commandArgs = commandArguments.hasArguments === false ? ["init"] : cliArguments.slice(1);
    return cli.run(commandName, commandArgs)
        .then(() => {
        process.exit(0);
    });
})
    .catch((error) => {
    console.log(error);
    process.exit(1);
});
;
//# sourceMappingURL=nodevolution-cli.js.map