#!/usr/bin/env node
import {CLI, CommandArguments} from "../src/index";
import {LogLevel} from "nodevolution-framework";

let cliArguments = process.argv.slice(2);
let commandArguments: CommandArguments = new CommandArguments(cliArguments);
let logLevel = commandArguments.hasOption("debug") ? LogLevel.Debug : LogLevel.Info;
let cli = new CLI();
cli.initialize(logLevel)
    .then(() => {

        let version = require("../package.json").version;

        if (commandArguments.hasOption("version") || commandArguments.hasOption("v")) {
            console.log(version);
            return process.exit(0);
        }

        if (commandArguments.hasOption("help") || commandArguments.hasOption("h")) {
            console.log(`Welcome to nodEvolution ${version}`);
            console.log(`Usage:`);
            console.log(`nx [command] [arguments...] [--options...]`);
            console.log(``);
            console.log(`# nx           -- initializes a new configuration in the current working directory`);
            return process.exit(0);
        }



        let commandName = commandArguments.hasArguments === false ? "config" : cliArguments[0].toLowerCase();
        let commandArgs = commandArguments.hasArguments === false ? ["init"] : cliArguments.slice(1);

        return cli.run(commandName, commandArgs)
            .then(() => {
                process.exit(0);
            });

    })
    .catch((error) => {
        console.log(error);
        process.exit(1);
    });
;


