"use strict";
const CommandArguments_1 = require("./commands/core/CommandArguments");
const nodevolution_framework_1 = require("nodevolution-framework");
const CLIModule_1 = require("./CLIModule");
const ConsoleLoggingPipeline_1 = require("./logging/ConsoleLoggingPipeline");
class CLI {
    initialize(logLevel) {
        let bootstrapper = new nodevolution_framework_1.FrameworkBootstrapper();
        bootstrapper
            .withIocContainer()
            .withLogging(logLevel, [new ConsoleLoggingPipeline_1.ConsoleLoggingPipeline(logLevel)])
            .bootstrap();
        this._container = bootstrapper.getContainer();
        this._container.load(new CLIModule_1.CLIModule());
        this._commandFactory = this._container.get("CommandFactory");
        this._logger = this.createLogger();
        return Promise.resolve();
    }
    run(commandName, args) {
        this._logger.debug(`try to instanciate command "${commandName}"`, { command: commandName, args: args });
        let command = this.createCommand(commandName);
        this._logger.debug(`found command, will now run it...`);
        return command.execute(new CommandArguments_1.CommandArguments(args));
    }
    createCommand(commandName) {
        return this._commandFactory.create(this._container, commandName);
    }
    createLogger() {
        let factory = this._container.get("LoggingServiceFactory");
        return factory.create("NXCLI");
    }
}
exports.CLI = CLI;
//# sourceMappingURL=CLI.js.map