"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const inquirer = require("inquirer");
const Process = require("process");
const nodevolution_framework_1 = require("nodevolution-framework");
const inversify_1 = require("inversify");
const ArgumentHandlerBase_1 = require("../../core/ArgumentHandlerBase");
let BumpArgumentHandler = class BumpArgumentHandler extends ArgumentHandlerBase_1.ArgumentHandlerBase {
    constructor(loggingServiceFactory, packageService, configurationService, versionService) {
        super();
        this._packageService = packageService;
        this._configurationService = configurationService;
        this._versionService = versionService;
        this._loggingService = loggingServiceFactory.create("LinkArgumentHandler");
    }
    initialize() {
        return new Promise((resolve) => {
            resolve();
        });
    }
    prepare(args) {
        return __awaiter(this, void 0, void 0, function* () {
            let workingDirectory = Process.cwd();
            this._loggingService.debug(`detected working directory ${workingDirectory}`);
            this._configuration = yield this.loadConfiguration(workingDirectory);
            this._packages = this._packageService.locatePackages(this._configuration.bump.files);
            let askForPackage = true;
            let askForVersionLevel = true;
            let packageName = args.next(args.get("bump"));
            if (packageName != undefined) {
                this._packageName = packageName.key;
                askForPackage = false;
            }
            let versionLevel = args.next(packageName);
            if (versionLevel != undefined) {
                this._versionLevelChoice = versionLevel.key;
                askForVersionLevel = false;
            }
            let questions = [
                {
                    name: "packageName",
                    message: "choose the package to bump",
                    type: "list",
                    choices: this._packages.map((x) => x.name),
                    when: askForPackage
                },
                {
                    name: "versionLevel",
                    message: "choose the version level",
                    type: "list",
                    choices: this.getVersionLevelChoices(),
                    when: askForVersionLevel
                }
            ];
            return yield inquirer.prompt(questions);
        });
    }
    handle(args, answers) {
        return __awaiter(this, void 0, void 0, function* () {
            this._loggingService.debug("start bump command");
            if (this._packageName == undefined) {
                this._packageName = answers["packageName"];
                if (this._packageName == undefined) {
                    this._loggingService.error("package name was not specified");
                    throw new Error("package name was not specified");
                }
            }
            if (this._versionLevelChoice == undefined) {
                this._versionLevelChoice = answers["versionLevel"];
                if (this._versionLevelChoice == undefined) {
                    this._loggingService.error("version level was not specified");
                    throw new Error("version level was not specified");
                }
            }
            let versionLevel = this._versionService.getVersionLevel(this._versionLevelChoice);
            if (versionLevel == undefined) {
                this._loggingService.error(`version level could not be mapped (${this._versionLevelChoice})`, this._versionLevelChoice);
                throw new Error(`version level could not be mapped (${this._versionLevelChoice})`);
            }
            this._loggingService.debug(`mapped version level to ${versionLevel}`, versionLevel);
            let initialPackage = this._packages.find((x) => {
                return x.name === this._packageName;
            });
            if (initialPackage == undefined) {
                this._loggingService.error(`specified package (${this._packageName}) to bump was not found.`, this._packageName);
                throw new Error(`specified package (${this._packageName}) to bump was not found.`);
            }
            let bumpInfos = yield this._versionService.createVersinBumpInfos(initialPackage, versionLevel, this._packages);
            bumpInfos.forEach((info) => {
                info.commands.forEach((cmd) => {
                    if (cmd instanceof nodevolution_framework_1.BumpPackageCommand) {
                        this._loggingService.info(`${cmd.packageName}: ${cmd.version} => ${cmd.newVersion}`);
                    }
                    else if (cmd instanceof nodevolution_framework_1.BumpDependencyCommand) {
                        this._loggingService.info(`\t${cmd.dependencyPackageName} ${cmd.version} => ${cmd.newVersion}`);
                    }
                    else if (cmd instanceof nodevolution_framework_1.BumpDevDependencyCommand) {
                        this._loggingService.info(`\t${cmd.dependencyPackageName} ${cmd.version} => ${cmd.newVersion}`);
                    }
                });
            });
            if (args.hasOption("f")) {
                yield this.persistChanges(bumpInfos);
            }
            else {
                let questions = [
                    { name: "persist", type: "confirm", message: "persist changes?" }
                ];
                let answers = yield inquirer.prompt(questions);
                if (answers["persist"] === true) {
                    yield this.persistChanges(bumpInfos);
                }
                else {
                    this._loggingService.warn(`aborted. changes not persited`);
                }
            }
        });
    }
    persistChanges(bumpInfos) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this._versionService.persistChanges(bumpInfos);
            this._loggingService.info(`persisted changes`);
        });
    }
    loadConfiguration(workingDirectory) {
        return __awaiter(this, void 0, void 0, function* () {
            let configurationFilePath = this._configurationService.search(workingDirectory);
            if (configurationFilePath === undefined) {
                this._loggingService.error(`no configuration file was detected. exiting`);
                return;
            }
            this._loggingService.debug(`loading configuration file from location ${configurationFilePath}`);
            let configuration = yield this._configurationService.load(configurationFilePath);
            this._loggingService.debug(`loaded configuration file`, configuration);
            if (configuration.bump == undefined) {
                this._loggingService.error(`configuration file has no bump section. Please create bump section with files.`, configuration);
                return;
            }
            if (configuration.bump.files == undefined) {
                this._loggingService.error(`bump section has no files defined. Please specify search directories in files section.`, configuration);
                return;
            }
            return configuration;
        });
    }
    getVersionLevelChoices() {
        let versionLevelChoices = [];
        for (let value in nodevolution_framework_1.VersionLevel) {
            if (typeof nodevolution_framework_1.VersionLevel[value] === "number") {
                versionLevelChoices.push(value);
            }
        }
        return versionLevelChoices;
    }
};
BumpArgumentHandler = __decorate([
    inversify_1.injectable(),
    __param(0, inversify_1.inject("LoggingServiceFactory")),
    __param(1, inversify_1.inject("PackageService")),
    __param(2, inversify_1.inject("ConfigurationService")),
    __param(3, inversify_1.inject("VersionService")),
    __metadata("design:paramtypes", [nodevolution_framework_1.LoggingServiceFactory,
        nodevolution_framework_1.PackageService,
        nodevolution_framework_1.ConfigurationService,
        nodevolution_framework_1.VersionService])
], BumpArgumentHandler);
exports.BumpArgumentHandler = BumpArgumentHandler;
//# sourceMappingURL=BumpArgumentHandler.js.map