import * as inquirer from "inquirer";
import Answers = inquirer.Answers;
import Question = inquirer.Question;
import * as Process from "process";
import {ConfigurationService} from "nodevolution-framework";
import {LoggingServiceFactory, LoggingService} from "nodevolution-framework";
import {inject, injectable} from "inversify";
import {ArgumentHandlerBase} from "../../core/ArgumentHandlerBase";
import {CommandArguments} from "../../core/CommandArguments";

@injectable()
export class InitArgumentHandler extends ArgumentHandlerBase {

    private _configurationService: ConfigurationService;
    private _loggingService: LoggingService;

    constructor(@inject("LoggingServiceFactory") loggingServiceFactory: LoggingServiceFactory,
                @inject("ConfigurationService") configurationService: ConfigurationService) {
        super();
        this._configurationService = configurationService;
        this._loggingService = loggingServiceFactory.create("InitArgumentHandler");
    }

    public initialize(): Promise<any> {
        return new Promise<any>((resolve) => {
            resolve();
        });
    }

    public prepare(args: CommandArguments): Promise<any> {
        return new Promise<any>((resolve) => {
            resolve();
        });
    }

    public async handle(args: CommandArguments, answers: Answers): Promise<any> {
        this._loggingService.debug(`initializing configuration`);
        let configuration = await this._configurationService.init();
        this._loggingService.debug(`configuration initialized`, configuration);
        configuration.link.files = ["."];
        configuration.bump.files = ["."];
        this._loggingService.debug(`added base directory "${Process.cwd()} to link files"`);

        return this._configurationService.save(Process.cwd(), configuration)
            .then(() => {
                this._loggingService.info("new configuration created");
            })
            .catch((error) => {
                this._loggingService.error("could not create new configuration", error);
            });
    }

}