"use strict";
class CommandArguments {
    constructor(args) {
        this._originalArgs = args;
        this._arguments = this.createArguments(args);
        this._options = this.createOptions(args);
    }
    get hasArguments() {
        return this._arguments.length > 0;
    }
    get hasOptions() {
        return this._options.length > 0;
    }
    has(arg) {
        return this._arguments.find((x) => {
            return x.key === arg;
        }) !== undefined;
    }
    get(arg) {
        return this._arguments.find((x) => {
            return x.key === arg;
        });
    }
    next(arg) {
        let argIndex = this._arguments.indexOf(arg) + 1;
        return argIndex > this._arguments.length ? undefined : this._arguments[argIndex];
    }
    hasOption(arg) {
        return this._options.find((x) => {
            return x.key === arg;
        }) !== undefined;
    }
    getOption(arg) {
        return this._options.find((x) => {
            return x.key === arg;
        });
    }
    createArguments(args) {
        let entries = [];
        args.forEach((arg) => {
            if (!arg.startsWith("--") && !arg.startsWith("-")) {
                entries.push(new Argument(arg));
            }
        });
        return entries;
    }
    createOptions(args) {
        let entries = [];
        for (let i = 0; i < args.length; i++) {
            let arg = args[i];
            if (arg.startsWith("--") || arg.startsWith("-")) {
                let value = args[args.indexOf(arg) + 1];
                let key = arg.startsWith("--") ? arg.substring(2, arg.length) : arg.substring(1, arg.length);
                entries.push(new Option(key, value));
                i++;
            }
        }
        return entries;
    }
}
exports.CommandArguments = CommandArguments;
class Argument {
    get key() {
        return this._key;
    }
    constructor(key) {
        this._key = key;
    }
}
exports.Argument = Argument;
class Option {
    get key() {
        return this._key;
    }
    get value() {
        return this._value;
    }
    constructor(key, value) {
        this._key = key;
        this._value = value;
    }
}
exports.Option = Option;
//# sourceMappingURL=CommandArguments.js.map