export class CommandArguments {

    private _originalArgs: Array<string>;
    private _arguments: Array<Argument>;
    private _options: Array<Option>;

    constructor(args: Array<string>) {
        this._originalArgs = args;
        this._arguments = this.createArguments(args);
        this._options = this.createOptions(args);
    }

    public get hasArguments(): boolean {
        return this._arguments.length > 0;
    }

    public get hasOptions(): boolean {
        return this._options.length > 0;
    }

    public has(arg: string): boolean {
        return this._arguments.find((x) => {
                return x.key === arg;
            }) !== undefined;
    }

    public get(arg: string): Argument {
        return this._arguments.find((x) => {
            return x.key === arg;
        });
    }

    public next(arg: Argument): Argument {
        let argIndex = this._arguments.indexOf(arg) + 1;
        return argIndex > this._arguments.length ? undefined : this._arguments[argIndex];
    }

    public hasOption(arg: string): boolean {
        return this._options.find((x) => {
                return x.key === arg;
            }) !== undefined;
    }

    public getOption(arg: string): Option {
        return this._options.find((x) => {
            return x.key === arg;
        });
    }

    private createArguments(args: Array<string>): Array<Argument> {
        let entries: Array<Argument> = [];
        args.forEach((arg) => {
            if (!arg.startsWith("--") && !arg.startsWith("-")) {
                entries.push(new Argument(arg));
            }
        });
        return entries;
    }

    private createOptions(args: Array<string>): Array<Option> {
        let entries: Array<Option> = [];
        for (let i = 0; i < args.length; i++) {
            let arg: string = args[i];
            if (arg.startsWith("--") || arg.startsWith("-")) {
                let value: string = args[args.indexOf(arg) + 1];
                let key = arg.startsWith("--") ? arg.substring(2, arg.length) : arg.substring(1, arg.length);
                entries.push(new Option(key, value));
                i++;
            }
        }
        return entries;
    }

}

export class Argument {

    private _key: string;

    public get key(): string {
        return this._key;
    }

    constructor(key: string) {
        this._key = key;
    }
}


export class Option {

    private _key: string;
    private _value: string;

    public get key(): string {
        return this._key;
    }

    public get value(): string {
        return this._value;
    }

    constructor(key: string, value: string) {
        this._key = key;
        this._value = value;
    }
}