import * as inquirer from "inquirer";
import Answers = inquirer.Answers;
import Question = inquirer.Question;
import * as Process from "process";
import * as Path from "path";
import {ConfigurationService, LinkService} from "nodevolution-framework";
import {LoggingServiceFactory, LoggingService} from "nodevolution-framework";
import {inject, injectable} from "inversify";
import {ArgumentHandlerBase} from "../../core/ArgumentHandlerBase";
import {CommandArguments} from "../../core/CommandArguments";

@injectable()
export class LinkArgumentHandler extends ArgumentHandlerBase {

    private _configurationService: ConfigurationService;
    private _linkService: LinkService;
    private _loggingService: LoggingService;

    constructor(@inject("LoggingServiceFactory") loggingServiceFactory: LoggingServiceFactory,
                @inject("ConfigurationService") configurationService: ConfigurationService,
                @inject("LinkService") linkService: LinkService) {
        super();
        this._configurationService = configurationService;
        this._linkService = linkService;
        this._loggingService = loggingServiceFactory.create("LinkArgumentHandler");
    }

    public initialize(): Promise<any> {
        return new Promise<any>((resolve) => {
            resolve();
        });
    }

    public prepare(args: CommandArguments): Promise<any> {
        return new Promise<any>((resolve) => {
            resolve();
        });
    }

    public async handle(args: CommandArguments, answers: Answers): Promise<any> {
        this._loggingService.debug("start linking command");
        let workingDirectory = Process.cwd();
        this._loggingService.debug(`detected working directory ${workingDirectory}`);

        let configurationFilePath = this._configurationService.search(workingDirectory);
        if (configurationFilePath === undefined) {
            this._loggingService.warn(`no configuration file was detected. exiting`);
            return;
        }
        this._loggingService.debug(`loading configuration file from location ${configurationFilePath}`);
        let configuration = await this._configurationService.load(configurationFilePath);
        this._loggingService.debug(`loaded configuration file`, configuration);

        this._loggingService.debug(`invoking linking service`, configuration.link);
        return this._linkService.link(configuration.link)
            .then(() => {
                this._loggingService.info(`linked projects successfully`);
            })
            .catch((error) => {
                this._loggingService.error("Error while linking projects", error);
                return;
            });

    }


}