import {CommandBase} from "../core/CommandBase";
import {CommandArguments} from "../core/CommandArguments";
import {injectable, inject} from "inversify";
import * as inquirer from "inquirer";

import Question = inquirer.Question;
import Answers = inquirer.Answers;
import {ArgumentHandlerFactory} from "./ArgumentHandlerFactory";
import {ArgumentHandlerBase} from "../core/ArgumentHandlerBase";
import {Argument} from "../core/CommandArguments";
import {CommandArgumentNotSpecifiedError} from "../errors/CommandArgumentNotSpecifiedError";
import {InvalidCommandArgumentError} from "../errors/InvalidCommandArgumentError";

@injectable()
export class Command extends CommandBase {

    private _argumentHandlerFactory: ArgumentHandlerFactory;

    constructor(@inject("ArgumentHandlerFactory") argumentHandlerFactory: ArgumentHandlerFactory) {
        super();
        this._argumentHandlerFactory = argumentHandlerFactory;
    }

    execute(args: CommandArguments): Promise<any> {
        let handler: ArgumentHandlerBase;
        handler = this._argumentHandlerFactory.create("unlink");
        return handler.initialize()
            .then(() => {
                return handler.prepare(args);
            }).then((answers: Answers) => {
                return handler.handle(args, answers);
            });
    }
}