"use strict";
const Chalk = require("chalk");
const nodevolution_framework_1 = require("nodevolution-framework");
class ConsoleLoggingPipeline {
    constructor(logLevel) {
        this._logLevel = logLevel;
    }
    log(logLevel, location, message, data) {
        if (logLevel > this._logLevel) {
            return;
        }
        let color = this.getChalkChain(logLevel);
        console.log(`[${new Date().toLocaleTimeString()}][${location}] ${color(message)}`);
    }
    getChalkChain(logLevel) {
        let colorAction;
        switch (logLevel) {
            case nodevolution_framework_1.LogLevel.Info:
                colorAction = Chalk.green;
                break;
            case nodevolution_framework_1.LogLevel.Warn:
                colorAction = Chalk.yellow;
                break;
            case nodevolution_framework_1.LogLevel.Error:
                colorAction = Chalk.bgRed;
                break;
            case nodevolution_framework_1.LogLevel.Debug:
                colorAction = Chalk.cyan;
                break;
        }
        return colorAction;
    }
}
exports.ConsoleLoggingPipeline = ConsoleLoggingPipeline;
//# sourceMappingURL=ConsoleLoggingPipeline.js.map