import * as Chalk from "chalk";
import {ILoggingPipeline, LogLevel} from "nodevolution-framework";

export class ConsoleLoggingPipeline implements ILoggingPipeline {
    private _logLevel: LogLevel;

    constructor(logLevel: LogLevel) {
        this._logLevel = logLevel;

    }

    log(logLevel: LogLevel, location: string, message: string, data: any): void {

        if (logLevel > this._logLevel) {
            return;
        }


        let color = this.getChalkChain(logLevel);
        console.log(`[${new Date().toLocaleTimeString()}][${location}] ${color(message)}`);
    }

    private getChalkChain(logLevel: LogLevel): Chalk.ChalkChain {
        let colorAction: Chalk.ChalkChain;
        switch (logLevel) {
            case LogLevel.Info:
                colorAction = Chalk.green;
                break;
            case LogLevel.Warn:
                colorAction = Chalk.yellow;
                break;
            case LogLevel.Error:
                colorAction = Chalk.bgRed;
                break;
            case LogLevel.Debug:
                colorAction = Chalk.cyan;
                break;
        }
        return colorAction;
    }
}